<?php

/**
 * @file
 * Post update functions for scorm_field.
 */

use Drupal\scorm_field\ScormPlayerSettingsInterface;
use Drupal\node\NodeInterface;

/**
 * Migrate data of config entity scorm_player_settings 
 * into new content entity scorm_field_settings! 
 */ 
function scorm_field_deploy_0001_migrate_player_settings() {

  $migrated_records = 0;

  // We need to migrate config entity "scorm_player_settings" to content entity "scorm_field_settings".
  $scorm_field_settings_storage = \Drupal::entityTypeManager()->getStorage('scorm_field_settings');
  
  $scorm_player_settings = \Drupal::entityTypeManager()->getStorage('scorm_player_settings')->loadMultiple();
  if (!empty($scorm_player_settings)) {

    $records_player_settings = count($scorm_player_settings);
    $migrated_records = 0;

    foreach ($scorm_player_settings as $setting) {
      if ($setting instanceof ScormPlayerSettingsInterface) {
        $node_uuid = substr($setting->id(),5);
        $node = \Drupal::service('entity.repository')->loadEntityByUuid('node', $node_uuid);
        if ($node instanceof NodeInterface) {
          $data = [
            'node' => $node->id(),
            'iframe_responsive' => $setting->getIframeResponsive(),
            'iframe_responsive_class' => $setting->getIframeResponsiveClass(),
            'iframe_scrolling' => $setting->getIframeScrolling(),
            'iframe_height' => $setting->getIframeHeight(),
            'iframe_width' => $setting->getIframeWidth(),
          ];

          try {
            $entity = $scorm_field_settings_storage->create($data);
            $entity->save();
            $migrated_records++;
          }
          catch (\Exception $exception) {
            \Drupal::logger('scorm_field')->warning('Problem migrating config entity record into content entity!');
          }
        }
      }
    }
  }

  return t('Migrated @migrated_records config entity entries!', ['@migrated_records' => $migrated_records]);

}

/**
 * Migrate data of content entity scorm_report
 * into new content entity attempt_mgmt_attempt! 
 */ 
function scorm_field_deploy_0002_migrate_scorm_report() {

  $migrated_records = 0;

  // We need to migrate config entity "scorm_player_settings" to content entity "scorm_field_settings".
  $attempt_mgmt_storage = \Drupal::entityTypeManager()->getStorage('attempt_mgmt_attempt');
  
  $scorm_report = \Drupal::entityTypeManager()->getStorage('scorm_report')->loadMultiple();
  if (!empty($scorm_report)) {

    $records_scorm_report = count($scorm_report);
    $migrated_records = 0;

    foreach ($scorm_report as $report) {
      $data = [
        'bundle' => 'scorm',
        'uid' => $report->uid,
        'entity_id' => $report->nid->target_id,
        'entity_type' => 'node',
        'closed' => TRUE,
        'temporary' => FALSE,
        'number_attempt' => 1,
        'created' => $report->created,
        'changed' => $report->changed,
        'session_uuid' => $report->session_uuid,
        'field_score_max' => $report->score_max->value,
        'field_score_min' => $report->score_min->value,
        'field_score_raw' => $report->score_raw->value,
        'field_scorm_status' => $report->status->value,
      ];

      try {
        $entity = $attempt_mgmt_storage->create($data);
        $entity->save();
        $migrated_records++;
      }
      catch (\Exception $exception) {
        \Drupal::logger('scorm_field')->warning('Problem migrating content entity scorm_reports into content entity attempts! ' . $exception->getMessage());
      }    
    }
  }

  return t('Migrated @migrated_records config entity entries!', ['@migrated_records' => $migrated_records]);

}
