<?php

namespace Drupal\scorm_field\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\node\NodeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\scorm_field\ScormFieldSettingsInterface;

/**
 * Class ScormFieldSettings.
 *
 * @package Drupal\scorm_field\Entity
 *
 * @ContentEntityType(
 *   id = "scorm_field_settings",
 *   label = @Translation("Scorm field settings"),
 *   handlers = {
 *     "views_data" = "Drupal\views\EntityViewsData"
 *   },
 *   base_table = "scorm_field_settings",
 *   fieldable = FALSE,
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid"
 *   }
 * )
 */
class ScormFieldSettings extends ContentEntityBase implements ScormFieldSettingsInterface {


  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['node'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Node'))
      ->setSetting('target_type', 'node')
      ->setSetting('handler', 'default');

    $fields['iframe_responsive'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Iframe responsive'))
      ->setDescription(t('A boolean indicating whether the iframe should be rendered responsive.'));
      
    $fields['iframe_responsive_class'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Iframe responsive class'))
      ->setDescription(t('A selection of resopnsive classes for the responsive iframe.'));

    $fields['iframe_scrolling'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Iframe scrolling'))
      ->setDescription(t('Set the iframe scrolling behaviour.'));
      
    $fields['iframe_width'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Iframe width'))
      ->setDescription(t('Set the iframe width when not responsive.'));
      
    $fields['iframe_height'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Iframe height'))
      ->setDescription(t('Set the iframe height when not responsive.')); 


    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function getNode() {
    return $this->get('node')->entity;
  }
  
  /**
   * {@inheritdoc}
   */
  public function getNodeId() {
    return $this->get('node')->target_id;
  } 
    

  /**
   * {@inheritdoc}
   */
  public function setNodeId($nid) {
    $this->set('node', $nid);
    return $this;
  }
  
  public function setNode(NodeInterface $node) {
    $this->set('node', $node->id());
    return $this;
  }
  
  /**
   * {@inheritdoc}
   */
  public function getIframeScrolling() {
    return $this->iframe_scrolling->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setIframeScrolling(string $iframe_scrolling) {
    $this->iframe_scrolling = $iframe_scrolling;
    return $this;
  }    

  /**
   * {@inheritdoc}
   */
  public function getIframeResponsive() {
    return $this->iframe_responsive->value;
  }

  /**
   * {@inheritdoc}
   */
  public function getIframeResponsiveClass() {
    return $this->iframe_responsive_class->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setIframeResponsive(bool $iframe_responsive) {
    $this->iframe_responsive = $iframe_responsive;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setIframeResponsiveClass(string $iframe_responsive_class) {
    $this->iframe_responsive_class = $iframe_responsive_class;
    return $this;
  }  

  /**
   * {@inheritdoc}
   */
  public function getIframeHeight() {
    return $this->iframe_height->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setIframeHeight(string $iframe_height) {
    $this->iframe_height = $iframe_height;
    return $this;
  }  

  /**
   * {@inheritdoc}
   */
  public function getIframeWidth() {
    return $this->iframe_width->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setIframeWidth(string $iframe_width) {
    $this->iframe_width = $iframe_width;
    return $this;
  }

  /**
   * {@inheritdoc}
   */  
  public function getScormPlayerSettings() {

    $player_settings = [];
    $player_settings['iframe_responsive'] = $this->getIframeResponsive();
    $player_settings['iframe_scrolling'] = $this->getIframeScrolling();
    $player_settings['iframe_responsive_class'] = $this->getIframeResponsiveClass();
    $player_settings['iframe_height'] = $this->getIframeHeight();
    $player_settings['iframe_width'] = $this->getIframeWidth();

    return $player_settings;

  }


}
