<?php

namespace Drupal\scorm_field;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\node\NodeInterface;

/**
 * Provides an interface defining a Scorm field settings entity.
 *
 * @ingroup scorm_field
 * @package Drupal\scorm_field
 */
interface ScormFieldSettingsInterface extends ContentEntityInterface {  
  
  /**
   * Gets the referenced node.
   *
   * @return \Drupal\node\NodeInterface
   *   The node entity.
   */
  public function getNode();
  
  /**
   * Gets the referenced node id.
   * 
   * @return int nid
   *   The node id of the node.
   */
  public function getNodeId();

  /**
   * Sets node id for the node.
   *
   * @param int $nid
   *   The node id.
   *
   * @return \Drupal\node\NodeInterface
   *   The node entity.
   */
  public function setNodeId(int $nid);
  
  /**
   * Sets node.
   *
   * @param \Drupal\node\NodeInterface $node
   *   The node object.
   *
   * @return \Drupal\node\NodeInterface
   *   The node entity.
   */  
  public function setNode(NodeInterface $node);
  
  /**
   * Gets the iframe scrolling.
   * 
   * @return string iframe_scrolling
   *   The iframe scrolling.
   */
  public function getIframeScrolling();

  /**
   * Sets the iframe scrolling.
   * 
   * @param string $iframe_scrolling
   *   The iframe scrolling option.
   *   
   * @return string iframe_scrolling
   *   The iframe scrolling.
   */
  public function setIframeScrolling(string $iframe_scrolling);

  /**
   * Gets the iframe responsive.
   * 
   * @return string iframe_responsive
   *   The iframe responsive.
   */
  public function getIframeResponsive();

  /**
   * Gets the iframe responsive class.
   * 
   * @return string iframe_responsive_class
   *   The iframe responsive class.
   */
  public function getIframeResponsiveClass();

  /**
   * Sets the iframe resopnsive class.
   * 
   * @param string $iframe_responsive_class
   *   The iframe responsive class option.
   *   
   * @return string iframe_resonsive_class
   *   The iframe responsive class.
   */
  public function setIframeResponsiveClass(string $iframe_responsive_class);

  /**
   * Gets the iframe height.
   * 
   * @return string iframe_height
   *   The iframe height.
   */
  public function getIframeHeight();

  /**
   * Sets the iframe height.
   * 
   * @param string iframe_height
   *   The iframe iframe_height.
   *   
   * @return string iframe_height
   *   The iframe height.
   */
  public function setIframeHeight(string $iframe_height);

  /**
   * Gets the iframe width.
   * 
   * @return string iframe_width
   *   The iframe width.
   */
  public function getIframeWidth();

  /**
   * Sets the iframe width.
   * 
   * @param string iframe_width
   *   The iframe iframe_width.
   *   
   * @return string iframe_width
   *   The iframe width.
   */
  public function setIframeWidth(string $iframe_width);
  
  
  /**
   * Get all relevant player settings.
   * 
   * @return array player_settings
   */  
  public function getScormPlayerSettings();  
  

}
